
CssDeadwood
===========


CssDeadwood is a tool to search for unused CSS selectors
by scanning given CSS files for CSS selectors and matching these against
HTML files (and optionally PHP/Python/Ruby/templates source code).
